<h1 align="center">tfs-mt</h1>
<div align="center">
    <a href="https://img.shields.io/github/v/release/Giovo17/tfs-mt" alt="Release">
        <img src="https://img.shields.io/github/v/release/Giovo17/tfs-mt"/></a>
    <a href="https://github.com/Giovo17/tfs-mt/actions/workflows/main.yml?query=branch%3Amain" alt="Build status">
      <img src="https://img.shields.io/github/actions/workflow/status/Giovo17/tfs-mt/main.yml?branch=main" /></a>
    <a href="https://github.com/Giovo17/tfs-mt/blob/main/LICENSE" alt="License">
        <img src="https://img.shields.io/github/license/Giovo17/tfs-mt" /></a>
    <a href="https://giovo17.github.io/tfs-mt" alt="Documentation">
        <img src="https://img.shields.io/badge/docs-giovo17.github.io/tfs--mt-blue" /></a>
    <a href="https://img.shields.io/github/commit-activity/m/Giovo17/tfs-mt" alt="Commit activity">
        <img src="https://img.shields.io/github/commit-activity/m/Giovo17/tfs-mt" /></a>
</div>
<br />


Transformer from scratch for Machine Translation
